@@ -6,8 +6,8 @@ import matplotlib.pyplot as plt
 import pandas as pd
 from IPython.display import HTML
 
-from digital_experiments.optmization import SEARCH_MODE, Modes
-from digital_experiments.querying import experiments_for, to_dataframe
+from .minimize import SEARCH_MODE, Modes
+from .querying import experiments_for, to_dataframe
 
 
 def get_blocks(arr):
@@ -91,9 +91,13 @@ def track_trials(x, y, root, callback=None, **kwargs):
     colours = df[f"metadata.{SEARCH_MODE}"].map(_colours)
 
     def _plot(i):
-        plt.scatter(xs[:i], ys[:i], c=colours[:i], s=20, linewidths=0, clip_on=False)
+        plt.scatter(
+            xs[:i], ys[:i], c=colours[:i], s=20, linewidths=0, clip_on=False
+        )
         for mode in df[f"metadata.{SEARCH_MODE}"].unique():
-            plt.scatter([], [], c=_colours[mode], label=mode.replace("-", " ").title())
+            plt.scatter(
+                [], [], c=_colours[mode], label=mode.replace("-", " ").title()
+            )
         plt.xlabel(x)
         plt.ylabel(y)
         if callback is not None:
